#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

subsuites = [
"base1",
"base2",
"base3",
"base4",
"basepar",
"bs",
"gw1",
"gw2",
"ldau",
"paw1",
"paw2",
"spin",
"tddft",
"udet",
"fold2bloch",
]

#: List of input files
inp_files = [
"tbase1_1.in", 
"tbase1_2.in",
"tbase1_3.in",
"tbase1_4.in",
"tbase1_5.in",
"tbase2_1.in",
"tbase2_2.in",
"tbase2_3.in",
"tbase2_4.in",
"tbase2_5.in",
"tbase3_1.in",
"tbase3_2.in",
"tbase3_3.in",
"tbase3_4.in",
"tbase3_5.in",
"tbase4_1.in",
"tbase4_2.in",
"tbase4_3.in",
"tbase4_4.in",
"tbase4_5.in",
"tbase4_6.in",
"tbase4_7.in",
"tbase4_8.in",
"tbasepar_1.in",
"tbasepar_2.in",
"tbs_1.in",
"tbs_2.in",
"tbs_3.in",
"tbs_4.in",
#"tbs_5.in",  # Template file (not used)
"tgw1_1.in",
"tgw1_2.in",
"tgw1_3.in",
"tgw1_4.in",
"tgw1_5.in",
"tgw1_6.in",
"tgw1_7.in",
"tgw1_8.in",
"tgw1_9.in",
"tgw2_1.in",
"tgw2_2.in",
"tgw2_3.in",
"tgw2_4.in",
"tldau_1.in",
"tldau_2.in",
"tldau_3.in",
"tldau_4.in",
"tpaw1_1.in",
"tpaw1_2.in",
"tpaw1_3.in",
"tpaw1_4.in",
"tpaw1_5.in",
"tpaw2_1.in",
"tpaw2_2.in",
"tspin_1.in",
"tspin_2.in",
"tspin_3.in",
"tspin_5.in",
"tspin_6.in",
"ttddft_1.in",
"tudet_1.in",
"tudet_2.in",
"tudet_3.in",
"tfold2bloch_1.in",
"tfold2bloch_2.in",
]
